﻿/*
 * CKEditor - The text editor for Internet - http://ckeditor.com
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 */

/**
 * @fileOverview Defines the {@link CKEDITOR.dom.document} class, which
 *		represents a DOM document.
 */

/**
 * Represents a DOM window.
 * @constructor
 * @augments CKEDITOR.dom.domObject
 * @param {Object} domWindow A native DOM window.
 * @example
 * var document = new CKEDITOR.dom.window( window );
 */
CKEDITOR.dom.window = function( domWindow )
{
	CKEDITOR.dom.domObject.call( this, domWindow );
};

CKEDITOR.dom.window.prototype = new CKEDITOR.dom.domObject();

CKEDITOR.tools.extend( CKEDITOR.dom.window.prototype,
	/** @lends CKEDITOR.dom.window.prototype */
	{
		/**
		 * Moves the selection focus to this window.
		 * @example
		 * var win = new CKEDITOR.dom.window( window );
		 * <b>win.focus()</b>;
		 */
		focus : function()
		{
			this.$.focus();
		},

		getViewPaneSize : function()
		{
			if ( 'innerWidth' in this.$ )
				return {
					width : this.$.innerWidth || 0,
					height : this.$.innerHeight || 0
				};
			else
				return {
					width : this.$.document.clientWidth || this.$.document.body.clientWidth || 0,
					height : this.$.document.clientHeight || this.$.document.body.clientHeight || 0
				};
		},

		getScrollPosition : function()
		{
			if ( 'pageXOffset' in this.$ )
				return {
					x : this.$.pageXOffset || 0,
					y : this.$.pageYOffset || 0
				};
			else
				return {
					x : this.$.document.documentElement.scrollLeft || this.$.document.body.scrollLeft || 0,
					y : this.$.document.documentElement.scrollTop || this.$.document.body.scrollTop || 0
				};
		}
	});
